MCRestimateidentity(sample.gene.matrix,classfactor,...) varSel.highest.t.stat(sample.gene.matrix,classfactor,theParameter=NULL,var.numbers=500,...)
varSel.highest.var(sample.gene.matrix,classfactor,theParameter=NULL,var.numbers=2000,...)
varSel.AUC(sample.gene.matrix, classfactor, theParameter=NULL,var.numbers=200,...) cluster.kmeans.mean(sample.gene.matrix,classfactor,theParameter=NULL,number.clusters=500,...)
varSel.removeManyNA(sample.gene.matrix,classfactor, theParameter=NULL, NAthreshold=0.25,...) varSel.impute.NA(sample.gene.matrix ,classfactor,theParameter=NULL,...)kmeans. If it is NULL then kmeans will be used to
form clusters of the genes. Otherwise the already existing clusters
will be used. In both ways there will be a calculation of the
metagene intensities afterwards. For the other functions either
NULL or a logical vector which indicates for every gene if it should
be left out from further analysis or notmetagene.kmeans.mean performs a kmeans clustering with
a number of clusters specified by 'number clusters' and takes the mean
of each cluster. varSel.highest.var selects a number (specified
by 'var.numbers') of variables with the highest variance. varSel.AUC chooses the
most discriminating variables due to the AUC criterium (the
library ROC is required).MCRestimatem <- matrix(c(rnorm(10,2,0.5),rnorm(10,4,0.5),rnorm(10,7,0.5),rnorm(10,2,0.5),rnorm(10,4,0.5),rnorm(10,2,0.5)),ncol=2)
cluster.kmeans.mean(m ,number.clusters=3)
Run the code above in your browser using DataLab